Welcome to ecyglpki’s documentation! — ecyglpki 0.2.0 documentation

### Navigation

- index
- modules |
- next |
- ecyglpki 0.2.0 documentation »

# Welcome to ecyglpki’s documentation!

Release: | 0.2.0
Date: | March 29, 2015

Contents:

- Problems
- Simplex Controls
- Basis Factorization Controls
- Interior Point Controls
- Integer Optimization Controls
- Branching Tree
- Graphs
  - Vertices
  - Arcs
- Examples
  - Gambling pool

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- ecyglpki 0.2.0 documentation »